@@ -1,6 +1,15 @@
-__version__ = "0.5.13"
+__version__ = "0.6.0"
 
-from .io import yaml_load, yaml_dump, save, load, json_load, json_dump
+from .io import (
+    yaml_load,
+    yaml_dump,
+    save,
+    load,
+    json_load,
+    json_dump,
+    jsonl_load,
+    jsonl_dump,
+)
 from .path import *
 from .progress_bar import probar
 from .performance import MeasureTime
