@@ -4,7 +4,7 @@ import os
 import pretty_errors
 import rich
 from rich import print
-from typing import Literal, Tuple
+from typing import Literal, Tuple, Union
 from pathlib import Path
 import datetime
 
@@ -667,7 +667,7 @@ Host {rsa_name}
             print(f"操作失败: {e}")
 
     @staticmethod
-    def download_images(keywords, num_images=50, engines="google", save_dir="downloaded_images"):
+    def download_images(keywords, num_images=50, engines="google", save_dir="downloaded_images", save_mapping=True):
         """
         从搜索引擎下载图片
         
@@ -677,6 +677,7 @@ Host {rsa_name}
             engines (str): 要使用的搜索引擎，多个引擎用逗号分隔 (默认: "bing,google")
                           支持: "bing", "google", "baidu"
             save_dir (str): 图片保存目录 (默认: "downloaded_images")
+            save_mapping (bool): 是否保存图像元数据到metadata.jsonl文件 (默认: True)
         
         Examples:
             # 下载单个关键词的图片
@@ -685,8 +686,11 @@ Host {rsa_name}
             # 下载多个关键词，指定数量和引擎
             sparrow download_images "猫咪,狗狗" --num_images=100 --engines="bing,google,baidu"
             
-            # 指定保存目录
+            # 指定保存目录（元数据默认保存）
             sparrow download_images "风景" --save_dir="my_images"
+            
+            # 禁用元数据保存
+            sparrow download_images "风景" --save_mapping=False
         """
         from .web.image_downloader import download_images_cli
         
@@ -723,7 +727,8 @@ Host {rsa_name}
                 keywords=keyword_list,
                 num_images=num_images,
                 engines=engine_list,
-                save_dir=save_dir
+                save_dir=save_dir,
+                save_mapping=save_mapping
             )
             
             # 打印详细统计信息
@@ -1040,6 +1045,92 @@ Host {rsa_name}
         # 运行异步函数
         asyncio.run(_run_call_folder_images())
 
+    def table_viewer(
+        self,
+        file_path: str,
+        port: int = 8080,
+        host: str = "127.0.0.1",
+        sheet_name: Union[str, int] = 0,
+        image_columns: str = None,
+        auto_detect_images: bool = True,
+        auto_open: bool = True
+    ):
+        """
+        启动交互式表格查看器，支持图片预览、筛选、编辑等功能
+        
+        Args:
+            file_path (str): 表格文件路径（支持.xlsx, .xls, .csv格式）
+            port (int): 服务器端口，默认8080
+            host (str): 服务器主机地址，默认127.0.0.1
+            sheet_name (Union[str, int]): Excel文件的sheet名称或索引，默认为0
+            image_columns (str): 指定图片列名，用逗号分隔，如"image,photo"
+            auto_detect_images (bool): 是否自动检测图片列，默认True
+            auto_open (bool): 是否自动打开浏览器，默认True
+            
+        Features:
+            - 支持大表格高性能展示（分页、虚拟滚动）
+            - 自动识别并预览图片URL（本地文件和网络链接）
+            - 强大的筛选功能（包含、等于、大于等多种条件）
+            - 双击单元格即可编辑内容
+            - 支持保存修改到原文件
+            - 可拖拽调整列宽
+            - 响应式设计，支持宽屏显示
+            
+        Examples:
+            # 基本用法
+            sparrow table_viewer "data.xlsx"
+            
+            # 指定端口和不自动打开浏览器
+            sparrow table_viewer "data.csv" --port=9090 --auto_open=False
+            
+            # 指定图片列（不使用自动检测）
+            sparrow table_viewer "products.xlsx" --image_columns="product_image,thumbnail" --auto_detect_images=False
+            
+            # 查看特定sheet
+            sparrow table_viewer "report.xlsx" --sheet_name="Sheet2"
+            
+        Performance:
+            - 支持百万级行数据（分页加载）
+            - 图片懒加载和缓存
+            - 内存优化的数据处理
+            - 快速搜索和筛选
+        """
+        from .table_viewer import TableViewerServer
+        from pathlib import Path
+        
+        # 验证文件
+        file_path = Path(file_path)
+        if not file_path.exists():
+            print(f"文件不存在: {file_path}")
+            return
+        
+        if not file_path.suffix.lower() in ['.csv', '.xlsx', '.xls']:
+            print(f"不支持的文件格式: {file_path.suffix}")
+            print("支持的格式: .csv, .xlsx, .xls")
+            return
+        
+        # 处理图片列参数
+        image_cols = None
+        if image_columns:
+            image_cols = [col.strip() for col in image_columns.split(',')]
+        
+        try:
+            # 创建并启动服务器
+            server = TableViewerServer(
+                file_path=str(file_path),
+                port=port,
+                host=host,
+                sheet_name=sheet_name,
+                image_columns=image_cols,
+                auto_detect_images=auto_detect_images
+            )
+            server.run(auto_open=auto_open)
+            
+        except Exception as e:
+            print(f"启动表格查看器失败: {e}")
+            import traceback
+            traceback.print_exc()
+
 
 def fire_commands():
     import fire
